from zavod.sinks.common import Sink
from zavod.sinks.json_entity import JSONEntitySink
from zavod.sinks.json_statement import JSONStatementSink

__all__ = ["Sink", "JSONEntitySink", "JSONStatementSink"]
